@@ -21,23 +21,31 @@ OpenGL.ERROR_CHECKING = False
 from OpenGL import GL, GLU
 import webbrowser
 from math import cos, sin, asin, acos, atan2, pi, sqrt
-qt5 = False
+
+USE_DEPRECATED_API = False
+
 try:
     # try PyQt5 first
     from PyQt5 import QtWidgets, QtCore, QtGui, QtOpenGL
     from PyQt5.QtCore import pyqtSignal as Signal
-    qt5 = True
 except ImportError:
-    # deprecated, will be removed at some point
+    # next try PySide2
     try:
-        from PyQt4 import QtGui, QtCore, QtGui, QtOpenGL
-        from PyQt4.QtCore import pyqtSignal as Signal
-        QtWidgets = QtGui
+        from PySide2 import QtCore, QtOpenGL, QtWidgets, QtGui
+        from PySide2.QtCore import Signal
     except ImportError:
-        # if PyQt* wasn't found, try PySide
-        from PySide import QtCore, QtGui, QtOpenGL
-        from PySide.QtCore import Signal
-        QtWidgets = QtGui
+        # next try PyQt4
+        # (deprecated, will be removed at some point)
+        USE_DEPRECATED_API = True
+        try:
+            from PyQt4 import QtGui, QtCore, QtGui, QtOpenGL
+            from PyQt4.QtCore import pyqtSignal as Signal
+        except ImportError:
+            # finally try PySide
+            from PySide import QtCore, QtGui, QtOpenGL
+            from PySide.QtCore import Signal
+        QtWidets = QtGui
+
 # The ConfigParser module has been renamed to configparser in Python 3.0
 try:
     import ConfigParser
@@ -118,6 +126,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self.environmentFile = None
         self.robotFile = None
         self.path = None
+        self.isGeometric = True
+        self.is3D = True
         self.mainWidget.problemWidget.robotTypeSelect.currentIndexChanged[int].connect(
             self.setRobotType)
         self.mainWidget.solveWidget.solveButton.clicked.connect(self.solve)
@@ -193,7 +203,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 config = ConfigParser.ConfigParser(strict=False)
             else:
                 config = ConfigParser.ConfigParser()
-            config.readfp(open(fname, 'r'))
+            config.read([fname])
             if config.has_option("problem", "start.z"):
                 if config.has_option("problem", "control"):
                     ctype = config.get("problem", "control")
@@ -825,7 +835,7 @@ class GLViewer(QtOpenGL.QGLWidget):
             self.timer.start(100.0/float(value))
             self.updatePathPose()
     def updatePathPose(self):
-        if self.solutionPath != None:
+        if self.solutionPath is not None:
             self.pathIndex = (self.pathIndex + 1) % len(self.solutionPath)
             self.updateGL()
     def setSolutionPath(self, path):
@@ -921,7 +931,7 @@ class GLViewer(QtOpenGL.QGLWidget):
             GL.glPopMatrix()
 
             # draw path pose(s)
-            if self.solutionPath != None:
+            if self.solutionPath is not None:
                 if self.animate:
                     GL.glPushMatrix()
                     GL.glMultMatrixf(self.solutionPath[self.pathIndex])
@@ -993,7 +1003,7 @@ class GLViewer(QtOpenGL.QGLWidget):
         self.lastPos = event.pos()
 
     def wheelEvent(self, event):
-        if qt5:
+        if not USE_DEPRECATED_API:
             self.scale = self.scale * pow(2.0, -event.angleDelta().y() / 240.0)
         else:
             self.scale = self.scale * pow(2.0, -event.delta() / 240.0)
